@@ -397,6 +397,7 @@ sub new
 	print STDERR "-0(Anystream): URL=$url2fetch=\n"  if ($DEBUG);
 	my $ua = LWP::UserAgent->new(@userAgentOps);		
 	$ua->timeout($uops{'timeout'});
+	$ua->max_size(1024);  #LIMIT FETCH-SIZE TO AVOID INFINITELY DOWNLOADING A STREAM!
 	$ua->cookie_jar({});
 	$ua->env_proxy;
 	my $response = $ua->get($url2fetch);
@@ -406,6 +407,15 @@ sub new
 		print STDERR $response->status_line  if ($DEBUG);
 	}
 	print STDERR "-1: html=$html=\n"  if ($DEBUG > 1);
+	return undef  unless ($html && $html =~ /\<\!DOCTYPE\s+(?:html|text)/);  #STEP 1 FAILED, INVALID STATION URL, PUNT!
+
+	$ua->max_size(undef);  #(NOW OK TO FETCH THE WHOLE DOCUMENT)
+	$response = $ua->get($url2fetch);
+	if ($response->is_success) {
+		$html = $response->decoded_content;
+	} else {
+		print STDERR $response->status_line  if ($DEBUG);
+	}
 	return undef  unless ($html);  #STEP 1 FAILED, INVALID STATION URL, PUNT!
 	$self->{'title'} = $self->{'id'} || $url;
 	$self->{'title'} = HTML::Entities::decode_entities($self->{'title'});
@@ -429,9 +439,9 @@ sub new
 			print STDERR "--2a: title=".$self->{'title'}."= stream=$streamURL=\n"  if ($DEBUG);
 		} elsif ($streamURL !~ /^http/o) {  #NO PREFIX, ASSUME RELATIVE TO THE FETCHED URL ("LONG DESC."):
 			(my $prefix = $self->{'description'}) =~ s#[\&\?\=\/].*$##;
-		print STDERR "--2b: desc=".$prefix."= stream=$streamURL=\n"  if ($DEBUG);
+			print STDERR "--2b: desc=".$prefix."= stream=$streamURL=\n"  if ($DEBUG);
 			$streamURL = $prefix . '/' . $streamURL;
-		}  #OTHERWISE STREAM URL IS A FULL URL (NO CHANGE).
+		} #OTHERWISE STREAM URL IS A FULL URL (NO CHANGE).
 		$streams .= "$ext=$streamURL|"  unless ($uops{'secure'} && $streamURL !~ /^https/o);
 	}
 	print STDERR "==streams=$streams=\n"  if ($DEBUG);
