@@ -385,10 +385,8 @@ TRYIT:
 	$response = $ua->get($url2fetch);
 	if ($response->is_success) {
 		$html = $response->decoded_content;
-print STDERR "---fetched: html=".substr($html,0,10)."=\n";
 	} else {
 		print STDERR $response->status_line  if ($DEBUG);
-print STDERR "---failed to fetch!\n";
 	}
 	print STDERR "-1: html=$html=\n"  if ($DEBUG > 1);
 	return undef  unless ($html && $self->{'id'});  #STEP 1 FAILED, INVALID PODCAST URL, PUNT!
@@ -457,9 +455,6 @@ print STDERR "---failed to fetch!\n";
 		$self->{'description'} =~ s#\<a.+?\<\/a\>##gs;
 		$self->{'description'} =~ s#\<[^\>]+?\>##gs;
 		$self->{'description'} =~ s#\s\s+# #gs;
-		$self->{'description'} = HTML::Entities::decode_entities($self->{'description'});
-		$self->{'description'} = uri_unescape($self->{'description'});
-		$self->{'description'} =~ s/(?:\%|\\?u?00)([0-9A-Fa-f]{2})/chr(hex($1))/egs;
 	}
 	$self->{'description'} ||= $1  if ($html =~ s#\<meta\s+property\=\"(?:og|twitter)\:description\"\s+content\=\"([^\"]+)\"\s*\/?\>##s);
 	$self->{'description'} ||= $1  if ($html =~ s#\,\"description\"\:\"([^\"]+)\"##s);
@@ -470,12 +465,6 @@ print STDERR "---failed to fetch!\n";
 		my $copyright = $1;
 		$self->{'year'} = $1  if ($copyright =~ /(\d\d\d\d)/s);
 	}
-	$self->{'title'} = HTML::Entities::decode_entities($self->{'title'});
-	$self->{'title'} = uri_unescape($self->{'title'});
-	$self->{'title'} =~ s/(?:\%|\\?u?00)([0-9A-Fa-f]{2})/chr(hex($1))/eg;
-	$self->{'description'} = HTML::Entities::decode_entities($self->{'description'});
-	$self->{'description'} = uri_unescape($self->{'description'});
-	$self->{'description'} =~ s/(?:\%|\\?u?00)([0-9A-Fa-f]{2})/chr(hex($1))/egs;
 	$self->{'iconurl'} = ($html =~ s#\,\"image_url\"\:\"([^\"]+)\"##s) ? $1 : '';
 	$self->{'iconurl'} =~ s#\\##g;
 	unless ($self->{'iconurl'}) {
@@ -491,6 +480,11 @@ print STDERR "---failed to fetch!\n";
 	}
 	$self->{'albumartist'} ||= $1  if ($html =~ m#\<meta\s+itemprop\=\"url\"\s+content\=\"([^\"]+)#s);
 	$self->{'album'} = $1  if ($html =~ m#\<meta\s+itemprop\=\"name\"\s+content\=\"([^\"]+)#s);
+	foreach my $f (qw(title description artist album)) {
+		$self->{$f} = HTML::Entities::decode_entities($self->{$f});
+		$self->{$f} = uri_unescape($self->{$f});
+		$self->{$f} =~ s/(?:\%|\\?u?00)([0-9A-Fa-f]{2})/chr(hex($1))/eg;
+	}
 	$self->{'imageurl'} = ($html =~ s#\,\"image_original_url\"\:\"([^\"]+)\"##s) ? $1 : '';
 	$self->{'imageurl'} =~ s#\\##g;
 	$self->{'imageurl'} ||= $self->{'iconurl'};  #MAKE SURE WE HAVE BOTH, OTHERWISE IMAGE:=ICON.
