@@ -376,8 +376,8 @@ sub new
 	push (@userAgentOps, 'agent', 'Mozilla/5.0 (X11; Linux x86_64; rv:68.0) Gecko/20100101 Firefox/68.0')
 			unless (defined $uops{'agent'});
 	$uops{'timeout'} = 10  unless (defined $uops{'timeout'});
-	$uops{'secure'} = 0    unless (defined $uops{'secure'});
-	$uops{'noiframes'} = 0    unless (defined $uops{'noiframes'});
+	$uops{'secure'} = 0  unless (defined $uops{'secure'});
+	$uops{'noiframes'} = 0  unless (defined $uops{'noiframes'});
 	$DEBUG = $uops{'debug'}  if (defined $uops{'debug'});
 	$FAST = $uops{'fast'}  if (defined $uops{'fast'});
 
@@ -452,33 +452,29 @@ RETRYIT:
 			my $html = '';
 			my $ua = LWP::UserAgent->new(@userAgentOps);		
 			$ua->timeout($uops{'timeout'});
+			$ua->max_size(1024);  #LIMIT FETCH-SIZE TO AVOID INFINITELY DOWNLOADING A STREAM!
 			$ua->cookie_jar({});
 			$ua->env_proxy;
 		 	my $response = $ua->get($url);
-		 	if ($response->is_success) {
-		 		$html = $response->decoded_content;
-		 	} else {
-		 		print STDERR $response->status_line  if ($DEBUG);
-		 		my $no_wget = system('wget','-V');
-		 		unless ($no_wget) {
-		 			print STDERR "\n..trying wget...\n"  if ($DEBUG);
-		 			$html = `wget -t 2 -T 20 -O- -o /dev/null \"$url\" 2>/dev/null `;
-		 		}
-		 	}
-
-			while ($html && $html =~ m#\<iframe([^\>]+)#s) {
-				my $one = $1;
-				my $embeddedURL = ($one =~ m#\"(https?\:\/\/[^\"]+)#s) ? $1 : '';
-				print STDERR "--embedded IFRAME url=$embeddedURL=\n"  if ($DEBUG);
-				if ($embeddedURL) {
-					my $haveStreamFinder = 0;
-					eval { require 'StreamFinder.pm'; $haveStreamFinder = 1; };
-					$embedded_video = new StreamFinder($embeddedURL, -noiframes => 1, -debug => 1)
-							if ($haveStreamFinder);
-					last;
+		 	$html = $response->decoded_content  if ($response->is_success);
+		 	if ($html =~ /\<\!DOCTYPE\s+(?:html|text)/) {  #IF WE'RE AN HTML DOCK (NOT A STREAM!), THEN FETCH THE WHOLE THING:
+				$ua->max_size(undef);  #(NOW OK TO FETCH THE WHOLE DOCUMENT)
+			 	my $response = $ua->get($url);
+			 	$html = $response->decoded_content  if ($response->is_success);
+				while ($html && $html =~ m#\<iframe([^\>]+)#s) {
+					my $one = $1;
+					my $embeddedURL = ($one =~ m#\"(https?\:\/\/[^\"]+)#s) ? $1 : '';
+					print STDERR "--embedded IFRAME url=$embeddedURL=\n"  if ($DEBUG);
+					if ($embeddedURL) {
+						my $haveStreamFinder = 0;
+						eval { require 'StreamFinder.pm'; $haveStreamFinder = 1; };
+						$embedded_video = new StreamFinder($embeddedURL, -noiframes => 1, -debug => 1)
+								if ($haveStreamFinder);
+						last;
+					}
 				}
+				return $embedded_video  if (defined($embedded_video) && $embedded_video->count() > 0);
 			}
-			return $embedded_video  if (defined($embedded_video) && $embedded_video->count() > 0);
 		}
 		print STDERR "..1:No MP4 streams found, try again for any (audio, etc.)...\n"  if ($DEBUG);
 		$try++;
@@ -507,7 +503,7 @@ RETRYIT:
 	push @{$self->{'streams'}}, @ytStreams;
 	$self->{'cnt'} = scalar @{$self->{'streams'}};
 	unless ($try || $self->{'cnt'} > 0) {  #IF NO STREAMS FOUND, RETRY WITHOUT THE SPECIFIC FILE-FORMAT:
-		print STDERR "..2:No MP4 streams found, try again for any (audio, etc.)...\n";
+		print STDERR "..2:No MP4 streams found, try again for any (audio, etc.)...\n"  if ($DEBUG);
 		$try++;
 		$ytdlArgs =~ s/\-f\s+\"([^\"]+)\"//;
 		goto RETRYIT  if ($1);
